@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,24 +13,22 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
-from typing import Callable, Dict, Optional, Sequence, Tuple
+from typing import Callable, Dict, Optional, Sequence, Tuple, Union
 
 from google.api_core import grpc_helpers  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+import google.auth  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
 
 from google.cloud.secretmanager_v1.types import resources
 from google.cloud.secretmanager_v1.types import service
-from google.iam.v1 import iam_policy_pb2 as iam_policy  # type: ignore
-from google.iam.v1 import policy_pb2 as policy  # type: ignore
-from google.protobuf import empty_pb2 as empty  # type: ignore
-
+from google.iam.v1 import iam_policy_pb2  # type: ignore
+from google.iam.v1 import policy_pb2  # type: ignore
+from google.protobuf import empty_pb2  # type: ignore
 from .base import SecretManagerServiceTransport, DEFAULT_CLIENT_INFO
 
 
@@ -60,7 +57,7 @@ class SecretManagerServiceGrpcTransport(SecretManagerServiceTransport):
         self,
         *,
         host: str = "secretmanager.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         channel: grpc.Channel = None,
@@ -74,7 +71,8 @@ class SecretManagerServiceGrpcTransport(SecretManagerServiceTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -184,7 +182,7 @@ class SecretManagerServiceGrpcTransport(SecretManagerServiceTransport):
     def create_channel(
         cls,
         host: str = "secretmanager.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -215,13 +213,15 @@ class SecretManagerServiceGrpcTransport(SecretManagerServiceTransport):
             google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
               and ``credentials_file`` are passed.
         """
-        scopes = scopes or cls.AUTH_SCOPES
+
+        self_signed_jwt_kwargs = cls._get_self_signed_jwt_kwargs(host, scopes)
+
         return grpc_helpers.create_channel(
             host,
             credentials=credentials,
             credentials_file=credentials_file,
-            scopes=scopes,
             quota_project_id=quota_project_id,
+            **self_signed_jwt_kwargs,
             **kwargs,
         )
 
@@ -367,7 +367,7 @@ class SecretManagerServiceGrpcTransport(SecretManagerServiceTransport):
         return self._stubs["update_secret"]
 
     @property
-    def delete_secret(self) -> Callable[[service.DeleteSecretRequest], empty.Empty]:
+    def delete_secret(self) -> Callable[[service.DeleteSecretRequest], empty_pb2.Empty]:
         r"""Return a callable for the delete secret method over gRPC.
 
         Deletes a [Secret][google.cloud.secretmanager.v1.Secret].
@@ -386,7 +386,7 @@ class SecretManagerServiceGrpcTransport(SecretManagerServiceTransport):
             self._stubs["delete_secret"] = self.grpc_channel.unary_unary(
                 "/google.cloud.secretmanager.v1.SecretManagerService/DeleteSecret",
                 request_serializer=service.DeleteSecretRequest.serialize,
-                response_deserializer=empty.Empty.FromString,
+                response_deserializer=empty_pb2.Empty.FromString,
             )
         return self._stubs["delete_secret"]
 
@@ -429,8 +429,8 @@ class SecretManagerServiceGrpcTransport(SecretManagerServiceTransport):
         Gets metadata for a
         [SecretVersion][google.cloud.secretmanager.v1.SecretVersion].
 
-        ``projects/*/secrets/*/versions/latest`` is an alias to the
-        ``latest``
+        ``projects/*/secrets/*/versions/latest`` is an alias to the most
+        recently created
         [SecretVersion][google.cloud.secretmanager.v1.SecretVersion].
 
         Returns:
@@ -463,8 +463,8 @@ class SecretManagerServiceGrpcTransport(SecretManagerServiceTransport):
         [SecretVersion][google.cloud.secretmanager.v1.SecretVersion].
         This call returns the secret data.
 
-        ``projects/*/secrets/*/versions/latest`` is an alias to the
-        ``latest``
+        ``projects/*/secrets/*/versions/latest`` is an alias to the most
+        recently created
         [SecretVersion][google.cloud.secretmanager.v1.SecretVersion].
 
         Returns:
@@ -588,7 +588,7 @@ class SecretManagerServiceGrpcTransport(SecretManagerServiceTransport):
     @property
     def set_iam_policy(
         self,
-    ) -> Callable[[iam_policy.SetIamPolicyRequest], policy.Policy]:
+    ) -> Callable[[iam_policy_pb2.SetIamPolicyRequest], policy_pb2.Policy]:
         r"""Return a callable for the set iam policy method over gRPC.
 
         Sets the access control policy on the specified secret. Replaces
@@ -612,15 +612,15 @@ class SecretManagerServiceGrpcTransport(SecretManagerServiceTransport):
         if "set_iam_policy" not in self._stubs:
             self._stubs["set_iam_policy"] = self.grpc_channel.unary_unary(
                 "/google.cloud.secretmanager.v1.SecretManagerService/SetIamPolicy",
-                request_serializer=iam_policy.SetIamPolicyRequest.SerializeToString,
-                response_deserializer=policy.Policy.FromString,
+                request_serializer=iam_policy_pb2.SetIamPolicyRequest.SerializeToString,
+                response_deserializer=policy_pb2.Policy.FromString,
             )
         return self._stubs["set_iam_policy"]
 
     @property
     def get_iam_policy(
         self,
-    ) -> Callable[[iam_policy.GetIamPolicyRequest], policy.Policy]:
+    ) -> Callable[[iam_policy_pb2.GetIamPolicyRequest], policy_pb2.Policy]:
         r"""Return a callable for the get iam policy method over gRPC.
 
         Gets the access control policy for a secret.
@@ -640,8 +640,8 @@ class SecretManagerServiceGrpcTransport(SecretManagerServiceTransport):
         if "get_iam_policy" not in self._stubs:
             self._stubs["get_iam_policy"] = self.grpc_channel.unary_unary(
                 "/google.cloud.secretmanager.v1.SecretManagerService/GetIamPolicy",
-                request_serializer=iam_policy.GetIamPolicyRequest.SerializeToString,
-                response_deserializer=policy.Policy.FromString,
+                request_serializer=iam_policy_pb2.GetIamPolicyRequest.SerializeToString,
+                response_deserializer=policy_pb2.Policy.FromString,
             )
         return self._stubs["get_iam_policy"]
 
@@ -649,7 +649,8 @@ class SecretManagerServiceGrpcTransport(SecretManagerServiceTransport):
     def test_iam_permissions(
         self,
     ) -> Callable[
-        [iam_policy.TestIamPermissionsRequest], iam_policy.TestIamPermissionsResponse
+        [iam_policy_pb2.TestIamPermissionsRequest],
+        iam_policy_pb2.TestIamPermissionsResponse,
     ]:
         r"""Return a callable for the test iam permissions method over gRPC.
 
@@ -675,8 +676,8 @@ class SecretManagerServiceGrpcTransport(SecretManagerServiceTransport):
         if "test_iam_permissions" not in self._stubs:
             self._stubs["test_iam_permissions"] = self.grpc_channel.unary_unary(
                 "/google.cloud.secretmanager.v1.SecretManagerService/TestIamPermissions",
-                request_serializer=iam_policy.TestIamPermissionsRequest.SerializeToString,
-                response_deserializer=iam_policy.TestIamPermissionsResponse.FromString,
+                request_serializer=iam_policy_pb2.TestIamPermissionsRequest.SerializeToString,
+                response_deserializer=iam_policy_pb2.TestIamPermissionsResponse.FromString,
             )
         return self._stubs["test_iam_permissions"]
 
